@@ -24,9 +24,7 @@ class ServiceDesk(AtlassianRestAPI):
 
         :return: Service Desks
         """
-        service_desks_list = self.get(
-            "rest/servicedeskapi/servicedesk", headers=self.experimental_headers
-        )
+        service_desks_list = self.get("rest/servicedeskapi/servicedesk", headers=self.experimental_headers)
         if self.advanced_mode:
             return service_desks_list
         else:
@@ -57,9 +55,7 @@ class ServiceDesk(AtlassianRestAPI):
         log.warning("Creating customer...")
         data = {"fullName": full_name, "email": email}
 
-        return self.post(
-            "rest/servicedeskapi/customer", headers=self.experimental_headers, data=data
-        )
+        return self.post("rest/servicedeskapi/customer", headers=self.experimental_headers, data=data)
 
     def get_customer_request(self, issue_id_or_key):
         """
@@ -76,9 +72,7 @@ class ServiceDesk(AtlassianRestAPI):
 
     def get_my_customer_requests(self):
         """ Returning requests where you are the assignee """
-        response = self.get(
-            "rest/servicedeskapi/request", headers=self.experimental_headers
-        )
+        response = self.get("rest/servicedeskapi/request", headers=self.experimental_headers)
         if self.advanced_mode:
             return response
         return (response or {}).get("values")
@@ -271,9 +265,7 @@ class ServiceDesk(AtlassianRestAPI):
         """
 
         return self.get(
-            "rest/servicedeskapi/request/{}/comment/{}".format(
-                issue_id_or_key, comment_id
-            ),
+            "rest/servicedeskapi/request/{}/comment/{}".format(issue_id_or_key, comment_id),
             headers=self.experimental_headers,
         )
 
@@ -291,9 +283,7 @@ class ServiceDesk(AtlassianRestAPI):
         :return:
         """
         url_without_sd_id = "rest/servicedeskapi/organization"
-        url_with_sd_id = "rest/servicedeskapi/servicedesk/{}/organization".format(
-            service_desk_id
-        )
+        url_with_sd_id = "rest/servicedeskapi/servicedesk/{}/organization".format(service_desk_id)
         params = {}
         if start is not None:
             params["start"] = int(start)
@@ -301,12 +291,8 @@ class ServiceDesk(AtlassianRestAPI):
             params["limit"] = int(limit)
 
         if service_desk_id is None:
-            return self.get(
-                url_without_sd_id, headers=self.experimental_headers, params=params
-            )
-        return self.get(
-            url_with_sd_id, headers=self.experimental_headers, params=params
-        )
+            return self.get(url_without_sd_id, headers=self.experimental_headers, params=params)
+        return self.get(url_with_sd_id, headers=self.experimental_headers, params=params)
 
     def get_organization(self, organization_id):
         """
@@ -422,19 +408,41 @@ class ServiceDesk(AtlassianRestAPI):
         return self.delete(url, headers=self.experimental_headers, data=data)
 
     # Attachments actions
-    def create_attachment(
-        self, service_desk_id, issue_id_or_key, filename, public=True, comment=None
-    ):
+    def create_attachments(self, service_desk_id, issue_id_or_key, filenames, public=True, comment=None):
         """
         Add attachment as a comment.
-
         Setting attachment visibility is dependent on the user's permission. For example,
         Agents can create either public or internal attachments,
         while Unlicensed users can only create internal attachments,
         and Customers can only create public attachments.
-
         An additional comment may be provided which will be prepended to the attachments.
+        :param service_desk_id: str
+        :param issue_id_or_key: str
+        :param filenames: Union(List[str], str), name, if file in current directory or full path to file
+        :param public: OPTIONAL: bool (default is True)
+        :param comment: OPTIONAL: str (default is None)
+        :return: Request info
+        """
+        # Create temporary attachment
+        temp_attachment_ids = []
+        if not isinstance(filenames, list):
+            filenames = [filenames]
 
+        for filename in filenames:
+            temp_attachment_id = self.attach_temporary_file(service_desk_id, filename)
+            temp_attachment_ids.append(temp_attachment_id)
+
+        # Add attachments
+        return self.add_attachments(issue_id_or_key, temp_attachment_ids, public, comment)
+
+    def create_attachment(self, service_desk_id, issue_id_or_key, filename, public=True, comment=None):
+        """
+        Add attachment as a comment.
+        Setting attachment visibility is dependent on the user's permission. For example,
+        Agents can create either public or internal attachments,
+        while Unlicensed users can only create internal attachments,
+        and Customers can only create public attachments.
+        An additional comment may be provided which will be prepended to the attachments.
         :param service_desk_id: str
         :param issue_id_or_key: str
         :param filename: str, name, if file in current directory or full path to file
@@ -442,51 +450,37 @@ class ServiceDesk(AtlassianRestAPI):
         :param comment: OPTIONAL: str (default is None)
         :return: Request info
         """
-        log.warning("Creating attachment...")
-
-        # Create temporary attachment
-        temp_attachment_id = self.attach_temporary_file(service_desk_id, filename)
-
-        # Add attachments
-        return self.add_attachment(issue_id_or_key, temp_attachment_id, public, comment)
+        log.info("Creating attachment...")
+        return self.create_attachments(service_desk_id, issue_id_or_key, filename, public=public, comment=comment)
 
     def attach_temporary_file(self, service_desk_id, filename):
         """
         Create temporary attachment, which can later be converted into permanent attachment
-
         :param service_desk_id: str
         :param filename: str
         :return: Temporary Attachment ID
         """
-        url = "rest/servicedeskapi/servicedesk/{}/attachTemporaryFile".format(
-            service_desk_id
-        )
+        url = "rest/servicedeskapi/servicedesk/{}/attachTemporaryFile".format(service_desk_id)
 
         with open(filename, "rb") as file:
-            result = self.post(
-                path=url,
-                headers=self.experimental_headers_general,
-                files={"file": file},
-            ).get("temporaryAttachments")
+            result = self.post(path=url, headers=self.experimental_headers, files={"file": file}).get(
+                "temporaryAttachments"
+            )
             temp_attachment_id = result[0].get("temporaryAttachmentId")
 
             return temp_attachment_id
 
-    def add_attachment(
-        self, issue_id_or_key, temp_attachment_id, public=True, comment=None
-    ):
+    def add_attachments(self, issue_id_or_key, temp_attachment_ids, public=True, comment=None):
         """
         Adds temporary attachment to customer request using attach_temporary_file function
-
         :param issue_id_or_key: str
-        :param temp_attachment_id: str, ID from result attach_temporary_file function
+        :param temp_attachment_ids: List[str], ID from result attach_temporary_file function
         :param public: bool (default is True)
         :param comment: str (default is None)
         :return:
         """
-        log.warning("Adding attachment")
         data = {
-            "temporaryAttachmentIds": [temp_attachment_id],
+            "temporaryAttachmentIds": temp_attachment_ids,
             "public": public,
             "additionalComment": {"body": comment},
         }
@@ -494,6 +488,18 @@ class ServiceDesk(AtlassianRestAPI):
 
         return self.post(url, headers=self.experimental_headers, data=data)
 
+    def add_attachment(self, issue_id_or_key, temp_attachment_id, public=True, comment=None):
+        """
+        Adds temporary attachment to customer request using attach_temporary_file function
+        :param issue_id_or_key: str
+        :param temp_attachment_id: str, ID from result attach_temporary_file function
+        :param public: bool (default is True)
+        :param comment: str (default is None)
+        :return:
+        """
+        log.info("Adding attachment")
+        return self.add_attachments(issue_id_or_key, [temp_attachment_id], public=public, comment=comment)
+
     # SLA actions
     def get_sla(self, issue_id_or_key, start=0, limit=50):
         """
@@ -532,6 +538,7 @@ class ServiceDesk(AtlassianRestAPI):
         return self.get(url, headers=self.experimental_headers)
 
     # Approvals
+
     def get_approvals(self, issue_id_or_key, start=0, limit=50):
         """
         Get all approvals on a request, for a given request ID/Key
@@ -561,9 +568,7 @@ class ServiceDesk(AtlassianRestAPI):
         :param approval_id: str
         :return:
         """
-        url = "rest/servicedeskapi/request/{0}/approval/{1}".format(
-            issue_id_or_key, approval_id
-        )
+        url = "rest/servicedeskapi/request/{0}/approval/{1}".format(issue_id_or_key, approval_id)
 
         return self.get(url, headers=self.experimental_headers)
 
@@ -576,9 +581,7 @@ class ServiceDesk(AtlassianRestAPI):
         :param decision: str
         :return:
         """
-        url = "rest/servicedeskapi/request/{0}/approval/{1}".format(
-            issue_id_or_key, approval_id
-        )
+        url = "rest/servicedeskapi/request/{0}/approval/{1}".format(issue_id_or_key, approval_id)
         data = {"decision": decision}
 
         return self.post(url, headers=self.experimental_headers, data=data)
@@ -653,9 +656,7 @@ class ServiceDesk(AtlassianRestAPI):
         :param limit: int
         :return: a page of issues
         """
-        url = "rest/servicedeskapi/servicedesk/{0}/queue/{1}/issue".format(
-            service_desk_id, queue_id
-        )
+        url = "rest/servicedeskapi/servicedesk/{0}/queue/{1}/issue".format(service_desk_id, queue_id)
         params = {}
 
         if start is not None:
